@@ -24,11 +24,11 @@ import (
 
 	"github.com/gohugoio/hugo/hugofs/glob"
 
+	"github.com/gohugoio/hugo/common/hexec"
 	"github.com/gohugoio/hugo/common/paths"
 
 	"github.com/pkg/errors"
 
-	"github.com/gohugoio/hugo/common/hexec"
 	"github.com/gohugoio/hugo/hugofs/files"
 
 	"github.com/gohugoio/hugo/hugofs"
@@ -56,16 +56,15 @@ func NewContent(h *hugolib.HugoSites, kind, targetPath string) error {
 	if h.BaseFs.Content.Dirs == nil {
 		return errors.New("no existing content directory configured for this project")
 	}
-	unlock, err := h.BaseFs.LockBuild()
-	if err != nil {
-		return fmt.Errorf("failed to acquire a build lock: %s", err)
-	}
-	defer unlock()
 
 	cf := hugolib.NewContentFactory(h)
 
 	if kind == "" {
-		kind = cf.SectionFromFilename(targetPath)
+		var err error
+		kind, err = cf.SectionFromFilename(targetPath)
+		if err != nil {
+			return err
+		}
 	}
 
 	b := &contentBuilder{
@@ -83,19 +82,39 @@ func NewContent(h *hugolib.HugoSites, kind, targetPath string) error {
 
 	b.setArcheTypeFilenameToUse(ext)
 
-	if b.isDir {
-		return b.buildDir()
+	withBuildLock := func() (string, error) {
+		unlock, err := h.BaseFs.LockBuild()
+		if err != nil {
+			return "", fmt.Errorf("failed to acquire a build lock: %s", err)
+		}
+		defer unlock()
+
+		if b.isDir {
+			return "", b.buildDir()
+		}
+
+		if ext == "" {
+			return "", errors.Errorf("failed to resolve %q to a archetype template", targetPath)
+		}
+
+		if !files.IsContentFile(b.targetPath) {
+			return "", errors.Errorf("target path %q is not a known content format", b.targetPath)
+		}
+
+		return b.buildFile()
+
 	}
 
-	if ext == "" {
-		return errors.Errorf("failed to resolve %q to a archetype template", targetPath)
+	filename, err := withBuildLock()
+	if err != nil {
+		return err
 	}
 
-	if !files.IsContentFile(b.targetPath) {
-		return errors.Errorf("target path %q is not a known content format", b.targetPath)
+	if filename != "" {
+		return b.openInEditorIfConfigured(filename)
 	}
 
-	return b.buildFile()
+	return nil
 
 }
 
@@ -192,18 +211,21 @@ func (b *contentBuilder) buildDir() error {
 		in.Close()
 		out.Close()
 	}
+
+	b.h.Log.Printf("Content dir %q created", filepath.Join(baseDir, b.targetPath))
+
 	return nil
 }
 
-func (b *contentBuilder) buildFile() error {
+func (b *contentBuilder) buildFile() (string, error) {
 	contentPlaceholderAbsFilename, err := b.cf.CreateContentPlaceHolder(b.targetPath)
 	if err != nil {
-		return err
+		return "", err
 	}
 
 	usesSite, err := b.usesSiteVar(b.archetypeFilename)
 	if err != nil {
-		return err
+		return "", err
 	}
 
 	var contentInclusionFilter *glob.FilenameFilter
@@ -216,16 +238,16 @@ func (b *contentBuilder) buildFile() error {
 	}
 
 	if err := b.h.Build(hugolib.BuildCfg{NoBuildLock: true, SkipRender: true, ContentInclusionFilter: contentInclusionFilter}); err != nil {
-		return err
+		return "", err
 	}
 
 	if err := b.applyArcheType(contentPlaceholderAbsFilename, b.archetypeFilename); err != nil {
-		return err
+		return "", err
 	}
 
-	b.h.Log.Infof("Content %q created", contentPlaceholderAbsFilename)
+	b.h.Log.Printf("Content %q created", contentPlaceholderAbsFilename)
 
-	return b.openInEditorIfConfigured(contentPlaceholderAbsFilename)
+	return contentPlaceholderAbsFilename, nil
 }
 
 func (b *contentBuilder) setArcheTypeFilenameToUse(ext string) {
@@ -234,7 +256,8 @@ func (b *contentBuilder) setArcheTypeFilenameToUse(ext string) {
 	if b.kind != "" {
 		pathsToCheck = append(pathsToCheck, b.kind+ext)
 	}
-	pathsToCheck = append(pathsToCheck, "default"+ext, "default")
+
+	pathsToCheck = append(pathsToCheck, "default"+ext)
 
 	for _, p := range pathsToCheck {
 		fi, err := b.archeTypeFs.Stat(p)
@@ -320,17 +343,19 @@ func (b *contentBuilder) openInEditorIfConfigured(filename string) error {
 		return nil
 	}
 
-	b.h.Log.Infof("Editing %q with %q ...\n", filename, editor)
+	b.h.Log.Printf("Editing %q with %q ...\n", filename, editor)
+	cmd, err := b.h.Deps.ExecHelper.New(
+		editor,
+		filename,
+		hexec.WithStdin(os.Stdin),
+		hexec.WithStderr(os.Stderr),
+		hexec.WithStdout(os.Stdout),
+	)
 
-	cmd, err := hexec.SafeCommand(editor, filename)
 	if err != nil {
 		return err
 	}
 
-	cmd.Stdin = os.Stdin
-	cmd.Stdout = os.Stdout
-	cmd.Stderr = os.Stderr
-
 	return cmd.Run()
 }
 
